@@ -42,12 +42,12 @@ class MainConfig:
     SaveCoTToDB = bool(True)
 
     # this should be set before startup
-    DBFilePath = str(r'C:\Users\natha\PycharmProjects\InDev\FreeTAKServerParent\FreeTAKServer\controllers\configuration\FTSDataBase.db')
+    DBFilePath = str(r'/root/FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
     version = 'FreeTAKServer-1.5 RC 1'
 
-    MainPath = str(Path(fr'C:/Users/natha/PycharmProjects/InDev/FreeTAKServerParent/FreeTAKServer'))
+    MainPath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer'))
 
     ExCheckMainPath = str(Path(fr'{MainPath}/ExCheck'))
 
@@ -86,4 +86,4 @@ class MainConfig:
 
     password = str('your pass')
 
-    websocketkey = "YourWEBSocketKey"
\ No newline at end of file
+    websocketkey = "YourWebsocketKey"
\ No newline at end of file
